@@ -46,7 +46,7 @@ class MultiplesExperimentos:
 
             for (nombre, valor) in self.lista_archivos.items():
                 if valor.get() is True:
-                    count =+ 1
+                    count += 1
                     print("conteo de experimentos: ", count)
                     nuevo_experimento = Experimento(str(nombre),
                                                     dimension_caja=self.dimension_caja,
@@ -109,7 +109,7 @@ class MultiplesExperimentos:
     def procesa_distancias_pendientes(self, epsilon):
         print("-------------------------------------------------------------------------------")
         for tipo_regresion_lineal in sorted(self.pendientes_regresion_lineal):
-            print("Regresión lineal a procesar distancias pendientes: ", tipo_regresion_lineal)
+            print("Regresion lineal a procesar distancias pendientes: ", tipo_regresion_lineal)
             lista_pendientes = self.pendientes_regresion_lineal[tipo_regresion_lineal]
             print("Lista de pendientes para", tipo_regresion_lineal, ": ", lista_pendientes)
             resultados_pendientes_funcion_signo = m_dp.procesa_lista_pendientes_funcion_signo(lista_pendientes,
@@ -119,11 +119,11 @@ class MultiplesExperimentos:
 
     def procesa_diccionario_entropias(self):
         """
-        Se lee uno de los diccionarios de entropía para conocer sus llaves. Por cada llave, se obtienen todos
-        los datos correspondientes a esa entropía para cada experimento. La lista resultante se guarda en un
-        diccionario, donde la llave es el tipo de entropía y el registro es la lista con los valores encontrados.
+        Se lee uno de los diccionarios de entropia para conocer sus llaves. Por cada llave, se obtienen todos
+        los datos correspondientes a esa entropia para cada experimento. La lista resultante se guarda en un
+        diccionario, donde la llave es el tipo de entropia y el registro es la lista con los valores encontrados.
 
-        El resultado es un diccionario con todas las entropías registradas, y listas con los valores de
+        El resultado es un diccionario con todas las entropias registradas, y listas con los valores de
         cada experimento
         """
 
@@ -157,7 +157,7 @@ class MultiplesExperimentos:
 
     def regresa_imagen_grafica(self, grafica):
         print("-----------------------------------------------")
-        print("Gráfica deseada:", grafica)
+        print("Grafica deseada:", grafica)
 
         fig = Figure(figsize=(6, 6))
         fig_plot = fig.add_subplot(111)
@@ -171,6 +171,12 @@ class MultiplesExperimentos:
             fig_plot.plot(range(1, cantidad_experimentos+1),
                           self.resultados_entropia["visitas_regiones"])
 
+        if grafica is 'entropia_aprox_visitas_regiones':
+            fig_plot.plot(range(1, cantidad_experimentos+1),
+                          self.resultados_entropia["visitas_regiones_aprox"], 'o')
+            fig_plot.plot(range(1, cantidad_experimentos+1),
+                          self.resultados_entropia["visitas_regiones_aprox"])
+
         elif grafica is 'entropia_visitas_regiones_preferidas':
             fig_plot.plot(range(1, cantidad_experimentos+1),
                           self.resultados_entropia["visitas_regiones_preferidas"], 'o')
